==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/mixin/mixins/common/client/MixinClientPacketListener.java <==
package de.keksuccino.fancymenu.mixin.mixins.common.client;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.mojang.authlib.GameProfile;
import de.keksuccino.fancymenu.customization.listener.listeners.Listeners;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.UUID;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2378;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_2596;
import net.minecraft.class_2703;
import net.minecraft.class_2775;
import net.minecraft.class_2797;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3468;
import net.minecraft.class_3469;
import net.minecraft.class_5892;
import net.minecraft.class_634;
import net.minecraft.class_638;
import net.minecraft.class_640;
import net.minecraft.class_746;

@Mixin(class_634.class)
public class MixinClientPacketListener {

    /** @reason Fire FancyMenu listener whenever the client sends a chat message. */
    @Inject(method = "send(Lnet/minecraft/network/protocol/Packet;)V", at = @At("HEAD"))
    private void before_sendChat_FancyMenu(class_2596<?> packet, CallbackInfo ci) {
        if (!(packet instanceof class_2797 chatPacket)) {
            return;
        }
        Listeners.ON_CHAT_MESSAGE_SENT.onChatMessageSent(class_2561.method_43470(chatPacket.comp_945()));
    }

    /** @reason Fire FancyMenu listener when another player joins the connected server. */
    @Inject(method = "handlePlayerInfo", at = @At("HEAD"))
    private void before_handlePlayerInfoUpdate_FancyMenu(class_2703 packet, CallbackInfo ci) {
        if (packet.method_11723() != class_2703.class_5893.field_29136) {
            return;
        }

        UUID localProfileId = class_310.method_1551().method_1548().method_44717();

        for (class_2703.class_2705 entry : packet.method_11722()) {
            GameProfile profile = entry.method_11726();
            if (profile == null) {
                continue;
            }

            UUID profileId = profile.getId();
            if (profileId == null || profileId.equals(localProfileId)) {
                continue;
            }

            Listeners.ON_OTHER_PLAYER_JOINED_WORLD.onOtherPlayerJoined(profile.getName(), profileId);
        }
    }

    /** @reason Fire FancyMenu listener when another player leaves the connected server. */
    @Inject(method = "handlePlayerInfo", at = @At("HEAD"))
    private void before_handlePlayerInfoRemove_FancyMenu(class_2703 packet, CallbackInfo ci) {
        if (packet.method_11723() != class_2703.class_5893.field_29140) {
            return;
        }

        UUID localProfileId = class_310.method_1551().method_1548().method_44717();
        class_634 self = (class_634)(Object)this;

        for (class_2703.class_2705 entry : packet.method_11722()) {
            GameProfile profile = entry.method_11726();
            if (profile == null) {
                continue;
            }

            UUID profileId = profile.getId();
            if (profileId == null || profileId.equals(localProfileId)) {
                continue;
            }

            class_640 playerInfo = self.method_2871(profileId);
            String playerName = profile.getName();
            if ((playerName == null || playerName.isBlank()) && playerInfo != null) {
                playerName = playerInfo.method_2966().getName();
            }
            Listeners.ON_OTHER_PLAYER_LEFT_WORLD.onOtherPlayerLeft(playerName, profileId);
        }
    }

    /** @reason Fire FancyMenu listener when another player dies in the current world. */
    @Inject(method = "handlePlayerCombatKill", at = @At(value = "INVOKE", target = "Lnet/minecraft/network/protocol/PacketUtils;ensureRunningOnSameThread(Lnet/minecraft/network/protocol/Packet;Lnet/minecraft/network/PacketListener;Lnet/minecraft/util/thread/BlockableEventLoop;)V", shift = At.Shift.AFTER))
    private void after_handlePlayerCombatKillEnsureThread_FancyMenu(class_5892 packet, CallbackInfo ci) {
        class_310 minecraft = class_310.method_1551();
        if (minecraft.field_1687 == null) {
            return;
        }

        class_1297 entity = minecraft.field_1687.method_8469(packet.method_34144());
        if (!(entity instanceof class_1657 player) || entity == minecraft.field_1724) {
            return;
        }

        class_243 deathPosition = player.method_19538();
        String playerName = player.method_7334().getName();
        if ((playerName == null || playerName.isBlank()) && player.method_5477() != null) {
            playerName = player.method_5477().getString();
        }

        Listeners.ON_OTHER_PLAYER_DIED.onOtherPlayerDied(playerName, player.method_5667(), deathPosition);
    }

    /** @reason Fire FancyMenu listener after the death screen opened for the local player. */
    @Inject(method = "handlePlayerCombatKill", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/Minecraft;setScreen(Lnet/minecraft/client/gui/screens/Screen;)V", shift = At.Shift.AFTER))
    private void after_handlePlayerCombatKillSetScreen_FancyMenu(class_5892 packet, CallbackInfo ci) {
        class_310 minecraft = class_310.method_1551();
        if (minecraft.field_1724 == null) {
            return;
        }

        Long daysSurvived = null;
        class_3469 stats = minecraft.field_1724.method_3143();
        if (stats != null) {
            int ticksSinceDeath = stats.method_15025(class_3468.field_15419.method_14956(class_3468.field_15400));
            if (ticksSinceDeath >= 0) {
                daysSurvived = (long)(ticksSinceDeath / 24000);
            }
        }

        class_243 deathPosition = minecraft.field_1724.method_19538();
        Listeners.ON_DEATH.onDeath(packet.method_34145(), daysSurvived, deathPosition.field_1352, deathPosition.field_1351, deathPosition.field_1350);
    }

    /** @reason Fire FancyMenu listener when the local player picks up an item entity. */
    @WrapOperation(method = "handleTakeItemEntity", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/ItemStack;shrink(I)V"))
    private void wrap_shrinkItem_FancyMenu(class_1799 stack, int amount, Operation<Void> operation, class_2775 packet) {
        class_310 minecraft = class_310.method_1551();
        class_746 localPlayer = minecraft.field_1724;
        if (localPlayer == null) {
            operation.call(stack, amount);
            return;
        }

        class_638 level = minecraft.field_1687;
        class_1297 potentialCollector = level != null ? level.method_8469(packet.method_11912()) : null;
        boolean isLocalCollector = potentialCollector == localPlayer;
        if (!isLocalCollector && potentialCollector == null) {
            isLocalCollector = packet.method_11912() == localPlayer.method_5628();
        }

        String itemKey = null;
        if (!stack.method_7960()) {
            class_2960 itemLocation = class_2378.field_11142.method_10221(stack.method_7909());
            if (itemLocation != null) {
                itemKey = itemLocation.toString();
            }
        }

        operation.call(stack, amount);

        if (!isLocalCollector || itemKey == null) {
            return;
        }

        Listeners.ON_ITEM_PICKED_UP.onItemPickedUp(itemKey);
    }

}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/mixin/mixins/common/client/MixinClientPacketListener.java <==
package de.keksuccino.fancymenu.mixin.mixins.common.client;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.mojang.authlib.GameProfile;
import de.keksuccino.fancymenu.customization.listener.listeners.Listeners;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.UUID;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_2703;
import net.minecraft.class_2775;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3468;
import net.minecraft.class_3469;
import net.minecraft.class_5892;
import net.minecraft.class_634;
import net.minecraft.class_638;
import net.minecraft.class_640;
import net.minecraft.class_746;
import net.minecraft.class_7828;
import net.minecraft.class_7923;

@Mixin(class_634.class)
public class MixinClientPacketListener {

    /** @reason Fire FancyMenu listener whenever the client sends a chat message. */
    @Inject(method = "sendChat", at = @At("HEAD"))
    private void before_sendChat_FancyMenu(String message, CallbackInfo ci) {
        Listeners.ON_CHAT_MESSAGE_SENT.onChatMessageSent(class_2561.method_43470(message));
    }

    /** @reason Fire FancyMenu listener when another player joins the connected server. */
    @Inject(method = "handlePlayerInfoUpdate", at = @At("HEAD"))
    private void before_handlePlayerInfoUpdate_FancyMenu(class_2703 packet, CallbackInfo ci) {
        if (!packet.method_46327().contains(class_2703.class_5893.field_29136)) {
            return;
        }

        UUID localProfileId = class_310.method_1551().method_1548().method_44717();

        for (class_2703.class_2705 entry : packet.method_46330()) {
            GameProfile profile = entry.comp_1107();
            if (profile == null) {
                continue;
            }

            UUID profileId = profile.id();
            if (profileId == null || profileId.equals(localProfileId)) {
                continue;
            }

            Listeners.ON_OTHER_PLAYER_JOINED_WORLD.onOtherPlayerJoined(profile.name(), profileId);
        }
    }

    /** @reason Fire FancyMenu listener when another player leaves the connected server. */
    @Inject(method = "handlePlayerInfoRemove", at = @At("HEAD"))
    private void before_handlePlayerInfoRemove_FancyMenu(class_7828 packet, CallbackInfo ci) {
        UUID localProfileId = class_310.method_1551().method_1548().method_44717();
        class_634 self = (class_634)(Object)this;

        for (UUID profileId : packet.comp_1105()) {
            if (profileId == null || profileId.equals(localProfileId)) {
                continue;
            }

            class_640 playerInfo = self.method_2871(profileId);
            String playerName = playerInfo != null ? playerInfo.method_2966().name() : null;
            Listeners.ON_OTHER_PLAYER_LEFT_WORLD.onOtherPlayerLeft(playerName, profileId);
        }
    }

    /** @reason Fire FancyMenu listener when another player dies in the current world. */
    @Inject(method = "handlePlayerCombatKill", at = @At(value = "INVOKE", target = "Lnet/minecraft/network/protocol/PacketUtils;ensureRunningOnSameThread(Lnet/minecraft/network/protocol/Packet;Lnet/minecraft/network/PacketListener;Lnet/minecraft/network/PacketProcessor;)V", shift = At.Shift.AFTER))
    private void after_handlePlayerCombatKillEnsureThread_FancyMenu(class_5892 packet, CallbackInfo ci) {
        class_310 minecraft = class_310.method_1551();
        if (minecraft.field_1687 == null) {
            return;
        }

        class_1297 entity = minecraft.field_1687.method_8469(packet.comp_2275());
        if (!(entity instanceof class_1657 player) || entity == minecraft.field_1724) {
            return;
        }

        class_243 deathPosition = player.method_73189();
        String playerName = player.method_7334().name();
        if ((playerName == null || playerName.isBlank()) && player.method_5477() != null) {
            playerName = player.method_5477().getString();
        }

        Listeners.ON_OTHER_PLAYER_DIED.onOtherPlayerDied(playerName, player.method_5667(), deathPosition);
    }

    /** @reason Fire FancyMenu listener after the death screen opened for the local player. */
    @Inject(method = "handlePlayerCombatKill", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/Minecraft;setScreen(Lnet/minecraft/client/gui/screens/Screen;)V", shift = At.Shift.AFTER))
    private void after_handlePlayerCombatKillSetScreen_FancyMenu(class_5892 packet, CallbackInfo ci) {
        class_310 minecraft = class_310.method_1551();
        if (minecraft.field_1724 == null) {
            return;
        }

        Long daysSurvived = null;
        class_3469 stats = minecraft.field_1724.method_3143();
        if (stats != null) {
            int ticksSinceDeath = stats.method_15025(class_3468.field_15419.method_14956(class_3468.field_15400));
            if (ticksSinceDeath >= 0) {
                daysSurvived = (long)(ticksSinceDeath / 24000);
            }
        }

        class_243 deathPosition = minecraft.field_1724.method_73189();
        Listeners.ON_DEATH.onDeath(packet.comp_2276(), daysSurvived, deathPosition.field_1352, deathPosition.field_1351, deathPosition.field_1350);
    }

    /** @reason Fire FancyMenu listener when the local player picks up an item entity. */
    @WrapOperation(method = "handleTakeItemEntity", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/ItemStack;shrink(I)V"))
    private void wrap_shrinkItem_FancyMenu(class_1799 stack, int amount, Operation<Void> operation, class_2775 packet) {
        class_310 minecraft = class_310.method_1551();
        class_746 localPlayer = minecraft.field_1724;
        if (localPlayer == null) {
            operation.call(stack, amount);
            return;
        }

        class_638 level = minecraft.field_1687;
        class_1297 potentialCollector = level != null ? level.method_8469(packet.method_11912()) : null;
        boolean isLocalCollector = potentialCollector == localPlayer;
        if (!isLocalCollector && potentialCollector == null) {
            isLocalCollector = packet.method_11912() == localPlayer.method_5628();
        }

        String itemKey = null;
        if (!stack.method_7960()) {
            class_2960 itemLocation = class_7923.field_41178.method_10221(stack.method_7909());
            if (itemLocation != null) {
                itemKey = itemLocation.toString();
            }
        }

        operation.call(stack, amount);

        if (!isLocalCollector || itemKey == null) {
            return;
        }

        Listeners.ON_ITEM_PICKED_UP.onItemPickedUp(itemKey);
    }

}
